@@ -8,11 +8,13 @@
 .onLoad <- function(libname, pkgname){
     if (is.null(getOption("dcmle.flavour")))
         options("dcmle.flavour"="jags")
+        options("dcmle.href"="http://dcr.r-forge.r-project.org/examples")
     invisible(NULL)
 }
 
 .onUnload <- function(libpath){
     options("dcmle.flavour"=NULL)
+    options("dcmle.href"=NULL)
     invisible(NULL)
 }
 
